<?php
/**
 * VW Dark Theme Customizer
 *
 * @package VW Dark
 */

/**
 * Add postMessage support for site title and description for the Theme Customizer.
 *
 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
 */

function vw_dark_custom_controls() {
	load_template( trailingslashit( get_template_directory() ) . '/inc/custom-controls.php' );
}
add_action( 'customize_register', 'vw_dark_custom_controls' );

function vw_dark_customize_register( $wp_customize ) {

	$wp_customize->get_setting( 'blogname' )->transport = 'postMessage'; 
	$wp_customize->get_setting( 'blogdescription' )->transport = 'postMessage';

	//Selective Refresh
	$wp_customize->selective_refresh->add_partial( 'blogname', array( 
		'selector' => '.logo .site-title a', 
	 	'render_callback' => 'vw_dark_Customize_partial_blogname',
	)); 

	$wp_customize->selective_refresh->add_partial( 'blogdescription', array( 
		'selector' => 'p.site-description', 
		'render_callback' => 'vw_dark_Customize_partial_blogdescription',
	));

	// add home page setting pannel
	$wp_customize->add_panel( 'vw_dark_panel_id', array(
		'capability' => 'edit_theme_options',
		'theme_supports' => '',
		'title' => esc_html__( 'VW Settings', 'vw-dark' ),
		'priority' => 10,
	));

	// Layout
	$wp_customize->add_section( 'vw_dark_left_right', array(
    	'title' => esc_html__('General Settings', 'vw-dark'),
		'panel' => 'vw_dark_panel_id'
	) );

	$wp_customize->add_setting('vw_dark_width_option',array(
        'default' => 'Full Width',
        'sanitize_callback' => 'vw_dark_sanitize_choices'
	));
	$wp_customize->add_control(new VW_Dark_Image_Radio_Control($wp_customize, 'vw_dark_width_option', array(
        'type' => 'select',
        'label' => esc_html__('Width Layouts','vw-dark'),
        'description' => esc_html__('Here you can change the width layout of Website.','vw-dark'),
        'section' => 'vw_dark_left_right',
        'choices' => array(
            'Full Width' => esc_url(get_template_directory_uri()).'/assets/images/full-width.png',
            'Wide Width' => esc_url(get_template_directory_uri()).'/assets/images/wide-width.png',
            'Boxed' => esc_url(get_template_directory_uri()).'/assets/images/boxed-width.png',
    ))));

	$wp_customize->add_setting('vw_dark_theme_options',array(
        'default' => 'Right Sidebar',
        'sanitize_callback' => 'vw_dark_sanitize_choices'
	));
	$wp_customize->add_control('vw_dark_theme_options',array(
        'type' => 'select',
        'label' => esc_html__('Post Sidebar Layout','vw-dark'),
        'description' => esc_html__('Here you can change the sidebar layout for posts. ','vw-dark'),
        'section' => 'vw_dark_left_right',
        'choices' => array(
            'Left Sidebar' => esc_html__('Left Sidebar','vw-dark'),
            'Right Sidebar' => esc_html__('Right Sidebar','vw-dark'),
            'One Column' => esc_html__('One Column','vw-dark'),
            'Grid Layout' => esc_html__('Grid Layout','vw-dark')
        ),
	) );

	$wp_customize->add_setting('vw_dark_page_layout',array(
        'default' => 'One_Column',
        'sanitize_callback' => 'vw_dark_sanitize_choices'
	));
	$wp_customize->add_control('vw_dark_page_layout',array(
        'type' => 'select',
        'label' => esc_html__('Page Sidebar Layout','vw-dark'),
        'description' => esc_html__('Here you can change the sidebar layout for pages. ','vw-dark'),
        'section' => 'vw_dark_left_right',
        'choices' => array(
            'Left_Sidebar' => esc_html__('Left Sidebar','vw-dark'),
            'Right_Sidebar' => esc_html__('Right Sidebar','vw-dark'),
            'One_Column' => esc_html__('One Column','vw-dark')
        ),
	) );

	// Selective Refresh
	$wp_customize->selective_refresh->add_partial( 'vw_dark_woocommerce_shop_page_sidebar', array( 'selector' => '.post-type-archive-product #sidebar', 
		'render_callback' => 'vw_dark_customize_partial_vw_dark_woocommerce_shop_page_sidebar', ) );

    // Woocommerce Shop Page Sidebar
	$wp_customize->add_setting( 'vw_dark_woocommerce_shop_page_sidebar',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'vw_dark_switch_sanitization'
    ) );
    $wp_customize->add_control( new VW_Dark_Toggle_Switch_Custom_Control( $wp_customize, 'vw_dark_woocommerce_shop_page_sidebar',array(
		'label' => esc_html__( 'Shop Page Sidebar','vw-dark' ),
		'section' => 'vw_dark_left_right'
    )));

    // Selective Refresh
	$wp_customize->selective_refresh->add_partial( 'vw_dark_woocommerce_single_product_page_sidebar', array( 'selector' => '.single-product #sidebar', 
		'render_callback' => 'vw_dark_customize_partial_vw_dark_woocommerce_single_product_page_sidebar', ) );

    //Woocommerce Single Product page Sidebar
	$wp_customize->add_setting( 'vw_dark_woocommerce_single_product_page_sidebar',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'vw_dark_switch_sanitization'
    ) );
    $wp_customize->add_control( new VW_Dark_Toggle_Switch_Custom_Control( $wp_customize, 'vw_dark_woocommerce_single_product_page_sidebar',array(
		'label' => esc_html__( 'Single Product Sidebar','vw-dark' ),
		'section' => 'vw_dark_left_right'
    )));

    // Pre-Loader
	$wp_customize->add_setting( 'vw_dark_loader_enable',array(
        'default' => 0,
        'transport' => 'refresh',
        'sanitize_callback' => 'vw_dark_switch_sanitization'
    ) );
    $wp_customize->add_control( new VW_Dark_Toggle_Switch_Custom_Control( $wp_customize, 'vw_dark_loader_enable',array(
        'label' => esc_html__( 'Pre-Loader','vw-dark' ),
        'section' => 'vw_dark_left_right'
    )));

	$wp_customize->add_setting('vw_dark_preloader_bg_color', array(
		'default'           => '#000',
		'sanitize_callback' => 'sanitize_hex_color',
	));
	$wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'vw_dark_preloader_bg_color', array(
		'label'    => __('Pre-Loader Background Color', 'vw-dark'),
		'section'  => 'vw_dark_left_right',
	)));

	$wp_customize->add_setting('vw_dark_preloader_border_color', array(
		'default'           => '#ffffff',
		'sanitize_callback' => 'sanitize_hex_color',
	));
	$wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'vw_dark_preloader_border_color', array(
		'label'    => __('Pre-Loader Border Color', 'vw-dark'),
		'section'  => 'vw_dark_left_right',
	)));

	//Header
	$wp_customize->add_section( 'vw_dark_header_section' , array(
    	'title' => __( 'Header Section', 'vw-dark' ),
		'panel' => 'vw_dark_panel_id'
	) );

	$wp_customize->add_setting( 'vw_dark_phone_number', array(
		'default'  => '',
		'sanitize_callback'	=> 'vw_dark_sanitize_phone_number'
	) );
	$wp_customize->add_control( 'vw_dark_phone_number', array(
		'label' => __('Add Phone Number','vw-dark'),
		'section' => 'vw_dark_header_section',
		'type'  => 'text',
	) );

	//Slider
	$wp_customize->add_section( 'vw_dark_slidersettings' , array(
    	'title'      => __( 'Slider Settings', 'vw-dark' ),
		'panel' => 'vw_dark_panel_id'
	) );

	$wp_customize->add_setting( 'vw_dark_slider_hide_show',array(
      'default' => 0,
      'transport' => 'refresh',
      'sanitize_callback' => 'vw_dark_switch_sanitization'
    ));  
    $wp_customize->add_control( new VW_Dark_Toggle_Switch_Custom_Control( $wp_customize, 'vw_dark_slider_hide_show',array(
      'label' => esc_html__( 'Show / Hide Slider','vw-dark' ),
      'section' => 'vw_dark_slidersettings'
    )));

     //Selective Refresh
    $wp_customize->selective_refresh->add_partial('vw_dark_slider_hide_show',array(
		'selector'        => '.slider-btn a',
		'render_callback' => 'vw_dark_customize_partial_vw_dark_slider_hide_show',
	));

	for ( $count = 1; $count <= 4; $count++ ) {
		$wp_customize->add_setting( 'vw_dark_slider_page' . $count, array(
			'default'           => '',
			'sanitize_callback' => 'vw_dark_sanitize_dropdown_pages'
		) );
		$wp_customize->add_control( 'vw_dark_slider_page' . $count, array(
			'label'    => __( 'Select Slider Page', 'vw-dark' ),
			'description' => __('Slider image size (450 x 250)','vw-dark'),
			'section'  => 'vw_dark_slidersettings',
			'type'     => 'dropdown-pages'
		) );
	}

	$wp_customize->add_setting( 'vw_dark_slider_title_hide_show',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'vw_dark_switch_sanitization'
    ));  
    $wp_customize->add_control( new vw_dark_Toggle_Switch_Custom_Control( $wp_customize, 'vw_dark_slider_title_hide_show',array(
		'label' => esc_html__( 'Show / Hide Slider Title','vw-dark' ),
		'section' => 'vw_dark_slidersettings'
    )));

    //Slider height
	$wp_customize->add_setting('vw_dark_slider_height',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_dark_slider_height',array(
		'label'	=> __('Slider Height','vw-dark'),
		'description'	=> __('Specify the slider height (px).','vw-dark'),
		'input_attrs' => array(
            'placeholder' => __( '500px', 'vw-dark' ),
        ),
		'section'=> 'vw_dark_slidersettings',
		'type'=> 'text'
	));

	$wp_customize->add_setting( 'vw_dark_slider_speed', array(
		'default'  => 4000,
		'sanitize_callback'	=> 'sanitize_text_field'
	) );
	$wp_customize->add_control( 'vw_dark_slider_speed', array(
		'label' => esc_html__('Slider Transition Speed','vw-dark'),
		'section' => 'vw_dark_slidersettings',
		'type'  => 'text',
	) );

	$wp_customize->add_setting( 'vw_dark_facebook_url', array(
		'default'  => '',
		'sanitize_callback'	=> 'esc_url_raw'
	) );
	$wp_customize->add_control( 'vw_dark_facebook_url', array(
		'label' => esc_html__('Add Facebook URL','vw-dark'),
		'input_attrs' => array(
            'placeholder' => __( 'https://www.facebook.com/', 'vw-dark' ),
        ),
		'section' => 'vw_dark_slidersettings',
		'type'  => 'url',
	) );

	$wp_customize->add_setting( 'vw_dark_twitter_url', array(
		'default'  => '',
		'sanitize_callback'	=> 'esc_url_raw'
	) );
	$wp_customize->add_control( 'vw_dark_twitter_url', array(
		'label' => esc_html__('Add Twitter URL','vw-dark'),
		'input_attrs' => array(
            'placeholder' => __( 'https://www.twitter.com/', 'vw-dark' ),
        ),
		'section' => 'vw_dark_slidersettings',
		'type'  => 'url',
	) );

	$wp_customize->add_setting( 'vw_dark_pinterest_url', array(
		'default'  => '',
		'sanitize_callback'	=> 'esc_url_raw'
	) );
	$wp_customize->add_control( 'vw_dark_pinterest_url', array(
		'label' => esc_html__('Add Pinterest URL','vw-dark'),
		'input_attrs' => array(
            'placeholder' => __( 'https://www.pinterest.com/', 'vw-dark' ),
        ),
		'section' => 'vw_dark_slidersettings',
		'type'  => 'url',
	) );

	$wp_customize->add_setting( 'vw_dark_youtube_url', array(
		'default'  => '',
		'sanitize_callback'	=> 'esc_url_raw'
	) );
	$wp_customize->add_control( 'vw_dark_youtube_url', array(
		'label' => esc_html__('Add Youtube URL','vw-dark'),
		'input_attrs' => array(
            'placeholder' => __( 'https://www.youtube.com/', 'vw-dark' ),
        ),
		'section' => 'vw_dark_slidersettings',
		'type'  => 'url',
	) );

	// Services Section
	$wp_customize->add_section('vw_dark_about_section',array(
		'title'	=> __('About Section','vw-dark'),
		'description' => __('Add section title and Select the post to display for about.','vw-dark'),
		'panel' => 'vw_dark_panel_id',
	));

	$wp_customize->add_setting( 'vw_dark_section_small_title', array(
		'default'           => '',
		'sanitize_callback' => 'sanitize_text_field'
	) );
	$wp_customize->add_control( 'vw_dark_section_small_title', array(
		'label'    => __( 'Add Section Small Title', 'vw-dark' ),
		'input_attrs' => array(
            'placeholder' => __( 'About Us', 'vw-dark' ),
        ),
		'section'  => 'vw_dark_about_section',
		'type'     => 'text'
	) );

	$args =  array('numberposts' => -1);
	$post_list = get_posts($args);
	$i = 0;
	$psts[]='Select';  
	foreach($post_list as $post){
		$psts[$post->post_title] = $post->post_title;
	}

	$wp_customize->add_setting('vw_dark_about_post',array(
		'default'	=> 'select',
		'sanitize_callback' => 'vw_dark_sanitize_choices',
	));
	$wp_customize->add_control('vw_dark_about_post',array(
		'type'    => 'select',
		'choices' => $psts,
		'label' => __('Select About Post','vw-dark'),
		'section' => 'vw_dark_about_section',
	));

	$wp_customize->add_setting( 'vw_dark_experience_years', array(
		'default'           => '',
		'sanitize_callback' => 'sanitize_text_field'
	) );
	$wp_customize->add_control( 'vw_dark_experience_years', array(
		'label'    => __( 'Add Experience Years', 'vw-dark' ),
		'input_attrs' => array(
            'placeholder' => __( '69', 'vw-dark' ),
        ),
		'section'  => 'vw_dark_about_section',
		'type'     => 'text'
	) );

	$wp_customize->add_setting( 'vw_dark_experience_text', array(
		'default'           => '',
		'sanitize_callback' => 'sanitize_text_field'
	) );
	$wp_customize->add_control( 'vw_dark_experience_text', array(
		'label'    => __( 'Add Experience Text', 'vw-dark' ),
		'input_attrs' => array(
            'placeholder' => __( 'We have 69+ years Experience.', 'vw-dark' ),
        ),
		'section'  => 'vw_dark_about_section',
		'type'     => 'text'
	) );

	//Blog Post
	$wp_customize->add_panel( 'vw_dark_blog_post_parent_panel', array(
		'title' => esc_html__( 'Blog Post Settings', 'vw-dark' ),
		'panel' => 'vw_dark_panel_id',
		'priority' => 20,
	));

	// Add example section and controls to the middle (second) panel
	$wp_customize->add_section( 'vw_dark_post_settings', array(
		'title' => esc_html__( 'Post Settings', 'vw-dark' ),
		'panel' => 'vw_dark_blog_post_parent_panel',
	));

	//Selective Refresh
	$wp_customize->selective_refresh->add_partial('vw_dark_toggle_postdate', array( 
		'selector' => '.post-main-box h2 a', 
		'render_callback' => 'vw_dark_Customize_partial_vw_dark_toggle_postdate', 
	));

	$wp_customize->add_setting( 'vw_dark_toggle_postdate',array(
        'default' => 1,
        'transport' => 'refresh',
        'sanitize_callback' => 'vw_dark_switch_sanitization'
    ) );
    $wp_customize->add_control( new VW_Dark_Toggle_Switch_Custom_Control( $wp_customize, 'vw_dark_toggle_postdate',array(
        'label' => esc_html__( 'Post Date','vw-dark' ),
        'section' => 'vw_dark_post_settings'
    )));

    $wp_customize->add_setting( 'vw_dark_toggle_author',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'vw_dark_switch_sanitization'
    ) );
    $wp_customize->add_control( new VW_Dark_Toggle_Switch_Custom_Control( $wp_customize, 'vw_dark_toggle_author',array(
		'label' => esc_html__( 'Author','vw-dark' ),
		'section' => 'vw_dark_post_settings'
    )));

    $wp_customize->add_setting( 'vw_dark_toggle_comments',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'vw_dark_switch_sanitization'
    ) );
    $wp_customize->add_control( new VW_Dark_Toggle_Switch_Custom_Control( $wp_customize, 'vw_dark_toggle_comments',array(
		'label' => esc_html__( 'Comments','vw-dark' ),
		'section' => 'vw_dark_post_settings'
    )));

    $wp_customize->add_setting( 'vw_dark_toggle_time',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'vw_dark_switch_sanitization'
    ) );
    $wp_customize->add_control( new VW_Dark_Toggle_Switch_Custom_Control( $wp_customize, 'vw_dark_toggle_time',array(
		'label' => esc_html__( 'Time','vw-dark' ),
		'section' => 'vw_dark_post_settings'
    )));

    $wp_customize->add_setting( 'vw_dark_featured_image_hide_show',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'vw_dark_switch_sanitization'
	));
    $wp_customize->add_control( new VW_Dark_Toggle_Switch_Custom_Control( $wp_customize, 'vw_dark_featured_image_hide_show', array(
		'label' => esc_html__( 'Featured Image','vw-dark' ),
		'section' => 'vw_dark_post_settings'
    )));

    $wp_customize->add_setting( 'vw_dark_toggle_tags',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'vw_dark_switch_sanitization'
	));
    $wp_customize->add_control( new VW_Dark_Toggle_Switch_Custom_Control( $wp_customize, 'vw_dark_toggle_tags', array(
		'label' => esc_html__( 'Tags','vw-dark' ),
		'section' => 'vw_dark_post_settings'
    )));

    $wp_customize->add_setting( 'vw_dark_excerpt_number', array(
		'default'              => 30,
		'type'                 => 'theme_mod',
		'transport' 		   => 'refresh',
		'sanitize_callback'    => 'vw_dark_sanitize_number_range',
		'sanitize_js_callback' => 'absint',
	) );
	$wp_customize->add_control( 'vw_dark_excerpt_number', array(
		'label'       => esc_html__( 'Excerpt length','vw-dark' ),
		'section'     => 'vw_dark_post_settings',
		'type'        => 'range',
		'settings'    => 'vw_dark_excerpt_number',
		'input_attrs' => array(
			'step'             => 5,
			'min'              => 0,
			'max'              => 50,
		),
	) );

	$wp_customize->add_setting('vw_dark_meta_field_separator',array(
		'default'=> '|',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_dark_meta_field_separator',array(
		'label'	=> __('Add Meta Separator','vw-dark'),
		'description' => __('Add the seperator for meta box. Example: "|", "/", etc.','vw-dark'),
		'section'=> 'vw_dark_post_settings',
		'type'=> 'text'
	));

    $wp_customize->add_setting('vw_dark_excerpt_settings',array(
        'default' => 'Excerpt',
        'transport' => 'refresh',
        'sanitize_callback' => 'vw_dark_sanitize_choices'
	));
	$wp_customize->add_control('vw_dark_excerpt_settings',array(
        'type' => 'select',
        'label' => esc_html__('Post Content','vw-dark'),
        'section' => 'vw_dark_post_settings',
        'choices' => array(
        	'Content' => esc_html__('Content','vw-dark'),
            'Excerpt' => esc_html__('Excerpt','vw-dark'),
            'No Content' => esc_html__('No Content','vw-dark')
        ),
	) );

    // Button Settings
	$wp_customize->add_section( 'vw_dark_button_settings', array(
		'title' => esc_html__( 'Button Settings', 'vw-dark' ),
		'panel' => 'vw_dark_blog_post_parent_panel',
	));

	$wp_customize->add_setting( 'vw_dark_button_border_radius', array(
		'default'              => 5,
		'type'                 => 'theme_mod',
		'transport' 		   => 'refresh',
		'sanitize_callback'    => 'vw_dark_sanitize_number_range',
		'sanitize_js_callback' => 'absint',
	) );
	$wp_customize->add_control( 'vw_dark_button_border_radius', array(
		'label'       => esc_html__( 'Button Border Radius','vw-dark' ),
		'section'     => 'vw_dark_button_settings',
		'type'        => 'range',
		'input_attrs' => array(
			'step'             => 1,
			'min'              => 1,
			'max'              => 50,
		),
	) );

	//Selective Refresh
	$wp_customize->selective_refresh->add_partial('vw_dark_button_text', array( 
		'selector' => '.post-main-box .more-btn a', 
		'render_callback' => 'vw_dark_Customize_partial_vw_dark_button_text', 
	));

    $wp_customize->add_setting('vw_dark_button_text',array(
		'default'=> esc_html__('Read More','vw-dark'),
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_dark_button_text',array(
		'label'	=> esc_html__('Add Button Text','vw-dark'),
		'input_attrs' => array(
            'placeholder' => esc_html__( 'Read More', 'vw-dark' ),
        ),
		'section'=> 'vw_dark_button_settings',
		'type'=> 'text'
	));

	// Related Post Settings
	$wp_customize->add_section( 'vw_dark_related_posts_settings', array(
		'title' => esc_html__( 'Related Posts Settings', 'vw-dark' ),
		'panel' => 'vw_dark_blog_post_parent_panel',
	));

	//Selective Refresh
	$wp_customize->selective_refresh->add_partial('vw_dark_related_post_title', array( 
		'selector' => '.related-post h3', 
		'render_callback' => 'vw_dark_Customize_partial_vw_dark_related_post_title', 
	));

    $wp_customize->add_setting( 'vw_dark_related_post',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'vw_dark_switch_sanitization'
    ) );
    $wp_customize->add_control( new VW_Dark_Toggle_Switch_Custom_Control( $wp_customize, 'vw_dark_related_post',array(
		'label' => esc_html__( 'Related Post','vw-dark' ),
		'section' => 'vw_dark_related_posts_settings'
    )));

    $wp_customize->add_setting('vw_dark_related_post_title',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_dark_related_post_title',array(
		'label'	=> esc_html__('Add Related Post Title','vw-dark'),
		'input_attrs' => array(
            'placeholder' => esc_html__( 'Related Post', 'vw-dark' ),
        ),
		'section'=> 'vw_dark_related_posts_settings',
		'type'=> 'text'
	));

   	$wp_customize->add_setting('vw_dark_related_posts_count',array(
		'default'=> 3,
		'sanitize_callback'	=> 'vw_dark_sanitize_number_absint'
	));
	$wp_customize->add_control('vw_dark_related_posts_count',array(
		'label'	=> esc_html__('Add Related Post Count','vw-dark'),
		'input_attrs' => array(
            'placeholder' => esc_html__( '3', 'vw-dark' ),
        ),
		'section'=> 'vw_dark_related_posts_settings',
		'type'=> 'number'
	));

	//Responsive Media Settings
	$wp_customize->add_section('vw_dark_responsive_media',array(
		'title'	=> esc_html__('Responsive Media','vw-dark'),
		'panel' => 'vw_dark_panel_id',
	));

    $wp_customize->add_setting( 'vw_dark_resp_slider_hide_show',array(
      	'default' => 0,
     	'transport' => 'refresh',
      	'sanitize_callback' => 'vw_dark_switch_sanitization'
    ));  
    $wp_customize->add_control( new VW_Dark_Toggle_Switch_Custom_Control( $wp_customize, 'vw_dark_resp_slider_hide_show',array(
      	'label' => esc_html__( 'Show / Hide Slider','vw-dark' ),
      	'section' => 'vw_dark_responsive_media'
    )));

    $wp_customize->add_setting( 'vw_dark_sidebar_hide_show',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'vw_dark_switch_sanitization'
    ));  
    $wp_customize->add_control( new VW_Dark_Toggle_Switch_Custom_Control( $wp_customize, 'vw_dark_sidebar_hide_show',array(
      	'label' => esc_html__( 'Show / Hide Sidebar','vw-dark' ),
      	'section' => 'vw_dark_responsive_media'
    )));

    $wp_customize->add_setting( 'vw_dark_resp_scroll_top_hide_show',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'vw_dark_switch_sanitization'
    ));  
    $wp_customize->add_control( new VW_Dark_Toggle_Switch_Custom_Control( $wp_customize, 'vw_dark_resp_scroll_top_hide_show',array(
      	'label' => esc_html__( 'Show / Hide Scroll To Top','vw-dark' ),
      	'section' => 'vw_dark_responsive_media'
    )));

	//Footer Text
	$wp_customize->add_section('vw_dark_footer',array(
		'title'	=> esc_html__('Footer Settings','vw-dark'),
		'panel' => 'vw_dark_panel_id',
	));	

	//Selective Refresh
	$wp_customize->selective_refresh->add_partial('vw_dark_footer_text', array( 
		'selector' => '.copyright p', 
		'render_callback' => 'vw_dark_Customize_partial_vw_dark_footer_text', 
	));
	
	$wp_customize->add_setting('vw_dark_footer_text',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));	
	$wp_customize->add_control('vw_dark_footer_text',array(
		'label'	=> esc_html__('Copyright Text','vw-dark'),
		'input_attrs' => array(
            'placeholder' => esc_html__( 'Copyright 2021, .....', 'vw-dark' ),
        ),
		'section'=> 'vw_dark_footer',
		'type'=> 'text'
	));

	$wp_customize->add_setting('vw_dark_copyright_alingment',array(
        'default' => 'center',
        'sanitize_callback' => 'vw_dark_sanitize_choices'
	));
	$wp_customize->add_control(new VW_Dark_Image_Radio_Control($wp_customize, 'vw_dark_copyright_alingment', array(
        'type' => 'select',
        'label' => esc_html__('Copyright Alignment','vw-dark'),
        'section' => 'vw_dark_footer',
        'settings' => 'vw_dark_copyright_alingment',
        'choices' => array(
            'left' => esc_url(get_template_directory_uri()).'/assets/images/copyright1.png',
            'center' => esc_url(get_template_directory_uri()).'/assets/images/copyright2.png',
            'right' => esc_url(get_template_directory_uri()).'/assets/images/copyright3.png'
    ))));

    $wp_customize->add_setting( 'vw_dark_hide_show_scroll',array(
    	'default' => 1,
      	'transport' => 'refresh',
      	'sanitize_callback' => 'vw_dark_switch_sanitization'
    ));  
    $wp_customize->add_control( new VW_Dark_Toggle_Switch_Custom_Control( $wp_customize, 'vw_dark_hide_show_scroll',array(
      	'label' => esc_html__( 'Show / Hide Scroll to Top','vw-dark' ),
      	'section' => 'vw_dark_footer'
    )));

    //Selective Refresh
	$wp_customize->selective_refresh->add_partial('vw_dark_scroll_to_top_icon', array( 
		'selector' => '.scrollup i', 
		'render_callback' => 'vw_dark_Customize_partial_vw_dark_scroll_to_top_icon', 
	));

    $wp_customize->add_setting('vw_dark_scroll_top_alignment',array(
        'default' => 'Right',
        'sanitize_callback' => 'vw_dark_sanitize_choices'
	));
	$wp_customize->add_control(new VW_Dark_Image_Radio_Control($wp_customize, 'vw_dark_scroll_top_alignment', array(
        'type' => 'select',
        'label' => esc_html__('Scroll To Top','vw-dark'),
        'section' => 'vw_dark_footer',
        'settings' => 'vw_dark_scroll_top_alignment',
        'choices' => array(
            'Left' => esc_url(get_template_directory_uri()).'/assets/images/layout1.png',
            'Center' => esc_url(get_template_directory_uri()).'/assets/images/layout2.png',
            'Right' => esc_url(get_template_directory_uri()).'/assets/images/layout3.png'
    ))));
}

add_action( 'customize_register', 'vw_dark_customize_register' );

load_template( trailingslashit( get_template_directory() ) . '/inc/logo/logo-resizer.php' );

/**
 * Singleton class for handling the theme's customizer integration.
 *
 * @since  1.0.0
 * @access public
 */
final class VW_Dark_Customize {

	/**
	 * Returns the instance.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return object
	 */
	public static function get_instance() {

		static $instance = null;

		if ( is_null( $instance ) ) {
			$instance = new self;
			$instance->setup_actions();
		}

		return $instance;
	}

	/**
	 * Constructor method.
	 *
	 * @since  1.0.0
	 * @access private
	 * @return void
	 */
	private function __construct() {}

	/**
	 * Sets up initial actions.
	 *
	 * @since  1.0.0
	 * @access private
	 * @return void
	 */
	private function setup_actions() {

		// Register panels, sections, settings, controls, and partials.
		add_action( 'customize_register', array( $this, 'sections' ) );

		// Register scripts and styles for the controls.
		add_action( 'customize_controls_enqueue_scripts', array( $this, 'enqueue_control_scripts' ), 0 );
	}

	/**
	 * Sets up the customizer sections.
	 *
	 * @since  1.0.0
	 * @access public
	 * @param  object  $manager
	 * @return void
	*/
	public function sections( $manager ) {

		// Load custom sections.
		load_template( trailingslashit( get_template_directory() ) . '/inc/section-pro.php' );

		// Register custom section types.
		$manager->register_section_type( 'VW_Dark_Customize_Section_Pro' );

		// Register sections.
		$manager->add_section( new VW_Dark_Customize_Section_Pro( $manager,'vw_dark_go_pro', array(
			'priority'   => 1,
			'title'    => esc_html__( 'VW DARK PRO', 'vw-dark' ),
			'pro_text' => esc_html__( 'UPGRADE PRO', 'vw-dark' ),
			'pro_url'  => esc_url('https://www.vwthemes.com/themes/black-and-white-wordpress-theme/'),
		) )	);

		// Register sections.
		$manager->add_section(new VW_Dark_Customize_Section_Pro($manager,'vw_dark_get_started_link',array(
			'priority'   => 1,
			'title'    => esc_html__( 'DOCUMENTATION', 'vw-dark' ),
			'pro_text' => esc_html__( 'DOCS', 'vw-dark' ),
			'pro_url'  => admin_url('themes.php?page=vw_dark_guide'),
		)));
	}

	/**
	 * Loads theme customizer CSS.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return void
	 */
	public function enqueue_control_scripts() {

		wp_enqueue_script( 'vw-dark-customize-controls', trailingslashit( get_template_directory_uri() ) . '/assets/js/customize-controls.js', array( 'customize-controls' ) );

		wp_enqueue_style( 'vw-dark-customize-controls', trailingslashit( get_template_directory_uri() ) . '/assets/css/customize-controls.css' );
	}
}

// Doing this customizer thang!
VW_Dark_Customize::get_instance();